import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {ButtonField, InputField, SelectField, useReadonlyContext} from "@rx-suite/ui";
import {CustomTarget, Parameter} from "../../../../stores/Types";
import {t} from "@lingui/macro";
import {Add, Delete} from "@material-ui/icons";
import {IconButton, Table, TableBody, TableCell, TableHead, TableRow} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";

export type CustomTargetFieldProps = {
    component: DashboardComponentModel,
    parameter: Parameter
};

const useStyles = makeStyles(theme => ({
    danger: {
        color: theme.palette.error.main
    }
}));

export const CustomTargetField: React.FunctionComponent<CustomTargetFieldProps> = observer(({component, parameter}) => {
    const classes = useStyles();
    const readOnly = useReadonlyContext();
    const combinations = component.viewModel.parameters[parameter.id] || [];
    return <div>
        {(combinations.length > 0) && <Table>
            <TableHead>
                <TableRow>
                    <TableCell>{t`Label`}</TableCell>
                    <TableCell>{t`Combines`}</TableCell>
                </TableRow>
            </TableHead>
            <TableBody>
                {combinations.map((target: CustomTarget, i: number) => {
                    const baseName = `parameters.${parameter.id}[${i}]`;
                    return <TableRow key={target.id}>
                        <TableCell><InputField name={`${baseName}.label`} value={target.label}
                                               onChange={component.handleChange} label={t`Label`} disabled={readOnly}/></TableCell>
                        <TableCell>
                            <SelectField onChange={component.handleSelectChange}
                                         label={t`Source Targets`}
                                         multiple={parameter.multiple}
                                         options={parameter.value_list!.reduce((options: { label: string, options: { label: string, value: string }[] }[], valueDef) => {
                                             let groupName = valueDef.group || '';
                                             let group = options.find((o: { label: string }) => o.label === groupName);
                                             if (!group) {
                                                 group = {
                                                     label: groupName,
                                                     options: []
                                                 };
                                                 options.push(group);
                                             }
                                             group.options.push({
                                                 label: valueDef.label as string,
                                                 value: valueDef.value
                                             });
                                             return options
                                         }, [])}
                                         name={`${baseName}.combines`}
                                         disabled={readOnly}
                                         value={target.combines}/>
                        </TableCell>
                        <TableCell><IconButton onClick={() => component.removeCustomTarget(target)}><Delete
                            className={classes.danger}/></IconButton></TableCell>
                    </TableRow>
                })}
            </TableBody>
        </Table>}
        <ButtonField text={t`New Combination`} startIcon={<Add/>} disabled={readOnly}
                     onClick={component.pushCustomTarget}/>
    </div>
});