import * as React from 'react';
import {observer} from 'mobx-react-lite';
import {Grid, GridItem} from '@rx-suite/ui';
import {DashboardModel} from "../../stores/DashboardStore";
import {DashboardGridItem} from "./DashboardGridItem";

export type DashboardGridProps = {
    dashboard: DashboardModel,
    editMode?: boolean
}

export const DashboardGrid: React.FunctionComponent<DashboardGridProps> = observer(({dashboard, editMode}) => {
    return <Grid onLayoutChange={dashboard.handleLayoutChange} compactType={'vertical'}>
        {dashboard.placements.map(p => (
            <GridItem key={p.getId()} id={p.getId().toString()} x={p.viewModel.x} y={p.viewModel.y}
                      width={p.viewModel.width} height={p.viewModel.height} fixed={!editMode}
                      onDelete={editMode ? () => {
                          dashboard.removePlacement(p);
                      } : undefined}
            >
                <DashboardGridItem key={p.getId()} placement={p} editMode={editMode}/>
            </GridItem>
        ))}
    </Grid>
});
